| Title: | Genome sequencing project metadata |
|---|---|
| Description: | Download genome and assembly reports from NCBI |
| Authors: | Chris Stubben |
| Maintainer: | Chris Stubben <[email protected]> |
| License: | GPL-3 |
| Version: | 3.43.0 |
| Built: | 2026-05-07 09:43:37 UTC |
| Source: | https://github.com/bioc/genomes |
Extracts the genus name from a scientific name
genus(x)genus(x)
x |
A vector of scientific names |
Removes single quotes, brackets and candidate qualifiers.
A vector of genus names
Chris Stubben
genus("[Bacillus] selenitireducens")genus("[Bacillus] selenitireducens")
Genome and assembly reports from the NCBI genomes FTP
reports(file, assembly = FALSE, ...)reports(file, assembly = FALSE, ...)
file |
file name, if missing then the files in the FTP directory are listed |
assembly |
use ASSEMBLY_REPORTS directory, default is GENOME_REPORTS |
... |
additional options passed to |
Uses read_delim in the readr package to read genome or assembly reports in the genomes FTP
A list of files if file name is missing, otherwise a data.frame with class c("tbl_df", "tbl", "data.frame"). If dplyr is loaded, then printing will return the first ten rows and not the first 10,000.
Chris Stubben
See ftp://ftp.ncbi.nih.gov/genomes/GENOME_REPORTS and ftp://ftp.ncbi.nih.gov/genomes/ASSEMBLY_REPORTS
reports() ## Not run: proks <- reports("prokaryotes.txt") ## End(Not run)reports() ## Not run: proks <- reports("prokaryotes.txt") ## End(Not run)
Extracts the species name from a scientific name
species(x)species(x)
x |
A vector of scientific names |
Removes single quotes, brackets and candidate qualifiers.
A vector of species names
Chris Stubben
species("Candidatus Carsonella ruddii PV")species("Candidatus Carsonella ruddii PV")